@@ -179,12 +179,20 @@ class OpenAPIV3DocumentationHandler:
 
         for path, path_item in paths.items():
             tag = self.get_tag(path_item) or ""
+
+            for operation in path_item.values():
+                # need to resolve possible references for requestBody
+                if "requestBody" in operation:
+                    operation["requestBody"] = self._resolve_opt_ref(
+                        operation["requestBody"]
+                    )
+
             groups[tag].append((path, path_item))
 
         return groups
 
     def get_schemas(self):
-        schemas = read_dict(self.doc, "components schemas")
+        schemas = read_dict(self.doc, "components", "schemas")
 
         if not schemas:
             return
@@ -287,7 +295,7 @@ class OpenAPIV3DocumentationHandler:
         """
         Gets a security scheme from the components section, by name.
         """
-        security_scheme = read_dict(self.doc, "components securitySchemes")
+        security_scheme = read_dict(self.doc, "components", "securitySchemes")
 
         if not security_scheme:  # pragma: no cover
             warnings.warn(
@@ -536,6 +544,10 @@ class OpenAPIV3DocumentationHandler:
         if is_reference(schema):
             return self.expand_references(self.resolve_reference(schema))
 
+        if schema is None:
+            # this should not happen, but we don't want the whole build to fail
+            return None
+
         clone = copy.deepcopy(schema)
 
         for key in list(clone.keys()):
